## This script gets the corret US Forest Service Forest Health Monitoring
## aerial survey codes (Appendix E) from a feature class and creates a file
## that is formatted with the correct input for the dropdown list in the
## analysis tool and for the dictionary in the actual tool script. 

import arcpy
from arcpy import env
import string
import sys
import os
import csv

#input parameters from user: the aerial survey, the output folder and
#US forest survice master list of codes
survey_data=arcpy.GetParameterAsText(0);
folder=arcpy.GetParameterAsText(1);
FSmasterCodes=arcpy.GetParameterAsText(2);

# set workspace to designated foldre
arcpy.env.workspace = folder;
arcpy.env.overwriteOutput=True;

#Use frequency tool to get the unique codes in the aerial survey data
codes_a = arcpy.Frequency_analysis(survey_data,folder+"\codes_1", "DCA1");

##flds=arcpy.ListFields(survey_data)
codes_b = arcpy.Frequency_analysis(survey_data,folder+"\codes_2", "DCA2");

#make a set (unique values) to hold codes contained in aerial survey data
codes=set();

#add codes to the set
with arcpy.da.SearchCursor(codes_a,"DCA1") as table_a:
    for c in table_a:
        codes.add(c);

with arcpy.da.SearchCursor(codes_b,"DCA2") as table_b:
    for c in table_b:
        codes.add(c);
code_list=[i[0] for i in codes];

#create dictionary to hold code names and codes
code_set={};

#open csv file and read contents. Find the codes that are in the aerial survey
#and match to codes in master list. Make keys that contain damage agent
#name and code. Add to dictionary with codes as value.
with open (FSmasterCodes) as master:
    master_codes = csv.DictReader(master);
    for cds in master_codes:
        for c in code_list:
            if cds['CODE'] == str(c):
                key = str(cds['CODE'])+"-"+str(cds['Common Name']);
                code_set[key]=int(cds['CODE']);
        
##Make a new file to hold the dictionary of damage agent names and codes
#and the list of names to go in the validation of the Arc tool to create
#a dropdwon menu
codes_sorted=(sorted(code_set));

#export results to a text file in the designated folder 
code_file = open(folder+'\code_lists.txt', 'w');
code_file.write("Sorted List of damage agents for dropdown menu"+
                "in Arc tool. This goes in tool validataion, under"+
                " 'def updateParameters(self)' as the list for 'self.params[3]'.\n\n");
code_file.write(str(codes_sorted));
code_file.write("\n\n\n List of damage agents and corresponding"
                +"codes to go in 'codes' list in FHdamageType.py\n\n");
code_file.write(str(code_set));
code_file.close();

